<?php
/*
Plugin Name: WooCommerce - NRGship
Plugin URI: http://www.woothemes.com/products/nrgship-integration/
Version: 3.1
Description: Add NRGship support to WooCommerce.
Author: NRG Software, LLC.
Author URI: mailto:support@nrgsoft.com
Text Domain: woo-nrgship
*/

/**
 * Required functions
 */
if ( ! function_exists( 'woothemes_queue_update' ) )
	require_once( 'woo-includes/woo-functions.php' );

/**
 * Plugin updates
 */
//woothemes_queue_update( plugin_basename( __FILE__ ), '9de8640767ba64237808ed7f245a49bb', '18734' );

// we CAN'T use "wc-api". SS uses next format to call url: [Your XML Endpoint]?action=export&start_date=[Start Date]&end_date=[End Date]&page=1
// we keep access via hook
add_action( "parse_request", "woo_nrg_parse_request" );
function woo_nrg_parse_request( &$wp ) {
	if ( $wp->request == "woo-nrgship-api" ) {
		include_once dirname( __FILE__ ) . "/handler.php";
		$hander = new WC_NRGship_Handler();
		die();
	}
}


// July 2013: add custom fields
register_activation_hook( __FILE__, 'woo_nrg_plugin_activate' );
function woo_nrg_plugin_activate() {
	global $wpdb;
	
	$wpdb->insert( $wpdb->postmeta, array( 'meta_key' => 'custom_field_nrgship_1' ) );
	$wpdb->insert( $wpdb->postmeta, array( 'meta_key' => 'custom_field_nrgship_2' ) );
	$wpdb->insert( $wpdb->postmeta, array( 'meta_key' => 'custom_field_nrgship_3' ) );
}

class WC_NRGship {
	public $domain;

	public function __construct() {
		$this->domain = 'woo-nrgship';
		$this->current_tab = ( isset( $_GET['tab'] ) ) ? $_GET['tab'] : 'general';

		load_plugin_textdomain( $this->domain, false, basename( dirname( __FILE__ ) ) . '/languages' );

		add_action( 'woocommerce_settings_tabs', array( &$this, 'tab' ), 10 );
		add_action( 'woocommerce_settings_tabs_woo_nrg', array( &$this, 'settings_tab_action' ) , 10 );
		add_action( 'woocommerce_update_options_woo_nrg', array( &$this, 'save_settings' ) , 10 );
		
		//19 June 2014 , Subscriptions renewal skips tracking meta
		add_filter( 'woocommerce_subscriptions_renewal_order_meta_query', array( &$this, 'subscriptions_renewal_order_meta_query' ) , 10 );
	}

	function tab() {
		$class = 'nav-tab';
		if ( $this->current_tab == 'woo_nrg' ) $class .= ' nav-tab-active';
		
		//was echo '<a href="' . admin_url( 'admin.php?page=woocommerce&tab=woo_nrg' ) . '" class="' . $class . '">NRGship</a>';
		echo '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=woo_nrg' ) . '" class="' . $class . '">NRGship</a>';
	}

	function shipname( $ship_method ) {
		return str_replace( "_", " ", str_replace( "WC_", "", $ship_method ) );
	}

	function init_form_fields()	{
		$this->form_fields = array(
			array(	'name' => __( 'NRGship plugin for WooCommerce', $this->domain ),
				'type' => 'title',
				'desc' => __( "Plugin Features:\n1) Exports orders ready for shipment to NRGship. Multiple order statuses may be chosen to export to NRGship.\n2) Updates orders inside WooCommerce with shipping and tracking information.\n3) Detects 3rd party \"Shipping Details\" plugins, and updates necessary plug-in related fields.\n4) Please refer to the <A href='http://www2.nrgsoft.com/pmwiki/ups_mac/pmwiki.php/AddedFeaturesAuto/WooCommerce' target='new'>NRGship for WooCommerce</A> documentation for full Installation, Config, and Testing instructions.", $this->domain ),
				'id' => 'about' ),
			array( 'type' => 'sectionend', 'id' => 'about' ),

			array(	'name' => __( 'Settings', $this->domain ),
				'type' => 'title',
				'desc' => '<font color="red">' . __( 'Enter same values in NRGship preferences for WooCommerce integration', $this->domain ) . '</font>',
				'id' => 'settings' ),
				array(
					'name' => __( 'Username', $this->domain ),
					'desc' => __( '', $this->domain ),
					'tip' => '',
					'id' => 'woo_nrg_username',
					'css' => '',
					'std' => '',
					'type' => 'text',
				),
				array(
					'name' => __( 'Password', $this->domain ),
					'desc' => __( '', $this->domain ),
					'tip' => '',
					'id' => 'woo_nrg_password',
					'css' => '',
					'std' => '',
					'type' => 'text',
				),
				array(
					'name' => __( 'Url to custom page', $this->domain ),
					'desc' => __( 'Set Permalinks in Settings>Permalinks. Do NOT use Default', $this->domain ),
					'tip' => '',
					'id' => 'woo_nrg_api_url',
					'css' => 'min-width:300px;color:grey',
					'std' => $this->url,
					'default' => $this->url, //for WooCommerce 2.0
					'type' => 'text',
				),
				array(
					'name' => __( 'Log requests', $this->domain ),
					'desc' => "<a target='_blank' href='{$this->url_log}'>" . __( 'View Log', $this->domain ) . "</a>",
					'tip' => '',
					'id' => 'woo_nrg_log_requests',
					'css' => '',
					'std' => '',
					'type' => 'checkbox',
				),
			array( 'type' => 'sectionend', 'id' => 'settings' ),

			array(	'name' => __( 'Alternate Authentication', $this->domain ),
				'type' => 'title',
				'desc' => '<font color="red">' . __( 'For use on webservers which run PHP in CGI mode. Add "?auth_key=value" to test url', $this->domain ) . '</font>',
				'id' => 'testing' ),
				array(
					'name' => __( 'Authentication Key', $this->domain ),
					'desc' => __( 'Enter long, random string here.', $this->domain ),
					'tip' => '',
					'id' => 'woo_nrg_auth_key',
					'css' => 'min-width:300px;color:grey',
					'std' => '',
					'type' => 'text',
				),
			array( 'type' => 'sectionend', 'id' => 'altAuth' ),

			array(	'name' => __( 'Export', $this->domain ),
				'type' => 'title',
				'desc' => '',
				'id' => 'export' ),
		);

		// may 2013
		$this->form_fields[] =
			array(
			'name' => __( 'Number of Records to Export Per Page', $this->domain ),
			'desc' => '',
			'tip' => '',
			'id' => 'woo_nrg_export_pagesize',
			'css' => '',
			'std' => '100',
			'default' => '100',
			'type' => 'select',
			'options' => array ( 50 => 50, 75 => 75, 100 => 100, 150 => 150 )
		);
		

		//add checkboxes for export status
		$count_status = count( $this->order_statuses );
		$status = current($this->order_statuses);
		for ( $i = 0; $i < $count_status; $i++ ) {
			$mode = "";
			if ( $i == 0 )
				$mode = "start";
			if ( $i == $count_status - 1 )
				$mode = "end";

			$this->form_fields[] =
				array(
					'name' => __( 'Order Status to look for when importing into NRGship', $this->domain ),
					'desc' => ucwords( $status ),
					'tip' => '',
					'id' => 'woo_nrg_export_status_' . md5( $status ),
					'css' => '',
					'std' => '',
					'checkboxgroup' => $mode,
					'type' => 'checkbox',
				);
			$status = next($this->order_statuses);
		}

		// for export shipment
		$count_status = count( $this->shipping_methods );
		reset( $this->shipping_methods );
		$method = current( $this->shipping_methods );
		for ( $i = 0; $i < $count_status; $i++ ) {
			$mode = "";
			if ( $i == 0 )
				$mode = "start";
			if ( $i == $count_status - 1 )
				$mode = "end";

			$this->form_fields[] =
				array(
					'name' => __( 'Shipping Methods to expose to NRGship', $this->domain ),
					'desc' => $method->title,
					'tip' => '',
					'id' => 'woo_nrg_export_shipping_' . $method->id,
					'css' => '',
					'std' => '',
					'checkboxgroup' => $mode,
					'type' => 'checkbox',
				);
			$method = next( $this->shipping_methods );
		}

		// July 2013 : export Coupon Code
		$this->form_fields[] =
			array(
			'name' => __( 'Export Order Coupon Code(s) to', $this->domain ),
			'desc' => '',
			'tip' => '',
			'id' => 'woo_nrg_export_coupon_position',
			'css' => '',
			'std' => 'CustomField1',
			'default' => 'CustomField1',
			'type' => 'select',
			'options' => array ( "None" => "None", "CustomField1" => "CustomField1", "CustomField2" => "CustomField2", "CustomField3" => "CustomField3" )
		);

		// 
		$this->form_fields[] =
			array(
				'name' => __( 'System Notes', $this->domain ),
				'desc_tip' => __( 'System Notes will be excluded from field InternalNotes (case insensitive)', $this->domain ),
				'tip' => '',
				'id' => 'woo_nrg_export_system_notes',
				'css' => '',
				'std' => '',
				'type' => 'textarea',
				'args' => 'cols=60 rows=5', 
				'custom_attributes'=> array( 'cols' => 60, 'rows' => 5 ), //for WooCommerce 2.0
			);


		$this->form_fields = array_merge( $this->form_fields, array(
			array( 'type' => 'sectionend', 'id' => 'export' ),
			array(	'name' => __( 'Import', $this->domain ),
				'type' => 'title',
				'desc' => $this->ship_details_plugin . $this->shipment_tracking_plugin,
				'id' => 'import' ),
				array(
					'name' => __( 'Order Status to move it to when the shipnotify action is presented', $this->domain ),
					'desc' => '',
					'tip' => '',
					'id' => 'woo_nrg_import_status',
					'css' => '',
					'std' => '',
					'type' => 'select',
					'options' => $this->order_statuses
				),
			array( 'type' => 'sectionend', 'id' => 'import' ),
		) );
	}

	function load_settings() {
		global $woocommerce;

		$this->shipment_tracking_plugin = $this->ship_details_plugin = "";
		if ( is_plugin_active( "wooshippinginfo/wootrackinfo.php" ) || is_plugin_active( "wooshippinginfo/wooshippinginfo.php" ) )
			$this->ship_details_plugin = '<h3><font color="blue">' . __( "Plugin 'Shipping Details for WooCommerce' detected. Script will update tracking information", $this->domain ) . '</font></h3>';
		if ( is_plugin_active( "woocommerce-shipment-tracking/shipment-tracking.php" ) || is_plugin_active( "shipment-tracking/shipment-tracking.php" ) )
			$this->shipment_tracking_plugin = '<h3><font color="blue">' . __( "Plugin 'Shipment Tracking for WooCommerce' detected. Script will update tracking information", $this->domain ) . '</font></h3>';

		// July 2013 url fixed
		$this->url = home_url( '/' ) . 'woo-nrgship-api';

		$folder = basename( dirname( __FILE__ ) );
		$this->url_log = site_url() . "/wp-content/plugins/$folder/handler.txt";

		//for 2.2+
		if( function_exists( "wc_get_order_statuses") ) {
			$this->order_statuses = wc_get_order_statuses() ;
		} else {
			$order_statuses = get_terms( "shop_order_status", "hide_empty=0" );
			$this->order_statuses = array();
			foreach ( $order_statuses as $status ) {
				$this->order_statuses[] = $status->name ;
			}
		}	

		$this->shipping_methods = $woocommerce->shipping->load_shipping_methods();

		if( !get_option( 'woo_nrg_export_system_notes' ) ) {
			$default_notes = file_get_contents( dirname( __FILE__ ) . '/data/system-notes.txt' );
			update_option( 'woo_nrg_export_system_notes' , $default_notes );
		}
	}

	function settings_tab_action() {
		global $woocommerce_settings;
		$current_tab = 'woo_nrg';

		$this->load_settings();

		// Display settings for this tab ( make sure to add the settings to the tab ).
		$this->init_form_fields();
		$woocommerce_settings[ $current_tab ] = $this->form_fields;
		woocommerce_admin_fields( $woocommerce_settings[ $current_tab ] );
	}



	function save_settings() {
		global $woocommerce_settings;
		$current_tab = 'woo_nrg';

		$this->load_settings();

		$this->init_form_fields();
		$woocommerce_settings[ $current_tab ] = $this->form_fields;
		woocommerce_update_options( $woocommerce_settings[ $current_tab ] );

		delete_option( 'woo_nrg_api_url' ); // don't update api url
		return true;
	}
	
	//19 June 2014 , Subscriptions renewal skips tracking meta
	function subscriptions_renewal_order_meta_query( $order_meta_query ){
		return $order_meta_query . " AND `meta_key` NOT IN ('custom_field_nrgship_1', 'custom_field_nrgship_2', 'custom_field_nrgship_3', 
			'_tracking_provider', '_tracking_number', '_date_shipped', 
			'_order_custtrackurl', '_order_custcompname', '_order_trackno', '_order_trackurl') ";
	}	
}

$GLOBALS['WC_NRGship'] = new WC_NRGship();